@@ -82,7 +82,7 @@ func commentBitbucketCmd(ctx *config.RunContext) *cobra.Command {
 			body, hasDiff, err := buildCommentBody(cmd, ctx, paths, output.MarkdownOptions{
 				WillUpdate:          prNumber != 0 && behavior == "update",
 				WillReplace:         prNumber != 0 && behavior == "delete-and-new",
-				IncludeFeedbackLink: true,
+				IncludeFeedbackLink: !ctx.Config.IsSelfHosted(),
 				OmitDetails:         extra.OmitDetails,
 				BasicSyntax:         true,
 			})
