@@ -935,6 +935,14 @@ func (b *Block) getHCLAttributes() hcl.Attributes {
 //
 // Would evaluate to a cty.Value of type Object with the instance_type Attribute holding the value "t3.medium".
 func (b *Block) Values() cty.Value {
+	if f, ok := blockValueFuncs[fmt.Sprintf("%s.%s", b.Type(), b.TypeLabel())]; ok {
+		return f(b)
+	}
+
+	return b.values()
+}
+
+func (b *Block) values() cty.Value {
 	values := make(map[string]cty.Value)
 
 	for _, attribute := range b.GetAttributes() {
@@ -1029,7 +1037,7 @@ func (b *Block) NameLabel() string {
 
 var (
 	countRegex   = regexp.MustCompile(`\[(\d+)\]$`)
-	foreachRegex = regexp.MustCompile(`\["(\w+)"\]$`)
+	foreachRegex = regexp.MustCompile(`\["(.*)"\]$`)
 )
 
 // Index returns the count index of the block using the name label.
@@ -1082,3 +1090,123 @@ func loadBlocksFromFile(file file, schema *hcl.BodySchema) (hcl.Blocks, error) {
 func stripCount(s string) string {
 	return foreachRegex.ReplaceAllString(countRegex.ReplaceAllString(s, ""), "")
 }
+
+// BlockValueFunc defines a type that returns a set of fake/mocked values for a given block type.
+type BlockValueFunc = func(b *Block) cty.Value
+
+var (
+	defaultAWSRegion = "us-east-1"
+	defaultGCPRegion = "us-central1"
+
+	blockValueFuncs = map[string]BlockValueFunc{
+		"data.aws_availability_zones": awsAvailabilityZonesValues,
+		"data.google_compute_zones":   googleComputeZonesValues,
+		"resource.random_shuffle":     randomShuffleValues,
+	}
+)
+
+// randomShuffleValues mocks the values returned from resource.random_shuffle
+// https://github.com/hashicorp/terraform-provider-random/blob/main/docs/resources/shuffle.md.
+// This resource uses the result_count attribute to return a slice of the input
+// attribute, which is randomly sorted.
+//
+// We don't randomly sort it here as it's unnecessary for us, and a consistent output
+// is probably better for debugging/tests.
+func randomShuffleValues(b *Block) cty.Value {
+	vals := b.values().AsValueMap()
+	inputs := vals["input"]
+	if !inputs.IsKnown() || !inputs.CanIterateElements() {
+		return b.values()
+	}
+
+	elements := inputs.AsValueSlice()
+
+	count, ok := vals["result_count"]
+	if !ok {
+		vals["result"] = inputs
+		return cty.ObjectVal(vals)
+	}
+
+	var x = 1
+	err := gocty.FromCtyValue(count, &x)
+	if err != nil {
+		b.logger.WithError(err).Debugf("couldn't load result_count to int for random_shuffle")
+	}
+
+	if x > len(elements)-1 {
+		vals["result"] = inputs
+		return cty.ObjectVal(vals)
+	}
+
+	var filtered []cty.Value
+	for i := 0; i < x; i++ {
+		filtered = append(filtered, elements[i])
+	}
+
+	vals["result"] = cty.ListVal(filtered)
+	return cty.ObjectVal(vals)
+}
+
+// googleComputeZonesValues returns the correct gcp zones for the data block region, data block provider region, or module region.
+// Used zones can be found in zones_gcp.go and can be regenerated by running go generate on this file.
+//
+//go:generate go run ../../tools/describezones/main.go gcp
+func googleComputeZonesValues(b *Block) cty.Value {
+	region := getRegionFromProvider(b, "google")
+
+	attr := b.GetAttribute("region")
+	if attr != nil {
+		var str string
+		attrRegion := attr.Value()
+		err := gocty.FromCtyValue(attrRegion, &str)
+		if err == nil {
+			region = str
+		} else {
+			b.logger.WithError(err).Debugf("could not parse gcp compute zone region")
+		}
+	}
+
+	if v, ok := gcpZones[region]; ok {
+		return v
+	}
+
+	return gcpZones[defaultGCPRegion]
+}
+
+// awsAvailabilityZonesValues returns the correct aws zones for the data block provider region or module region.
+// Used zones can be found in zones_aws.go and can be regenerated by running go generate on this file.
+//
+//go:generate go run ../../tools/describezones/main.go aws
+func awsAvailabilityZonesValues(b *Block) cty.Value {
+	region := getRegionFromProvider(b, "aws")
+	if v, ok := awsZones[region]; ok {
+		return v
+	}
+
+	return awsZones[defaultAWSRegion]
+}
+
+func getRegionFromProvider(b *Block, provider string) string {
+	region := b.context.Get(provider, "region")
+
+	attr := b.GetAttribute("provider")
+	if attr != nil {
+		v := attr.Value()
+		r := v.GetAttr("region")
+		if !r.IsNull() {
+			region = r
+		}
+	}
+
+	var str string
+	err := gocty.FromCtyValue(region, &str)
+	if err != nil {
+		if provider == "google" {
+			return defaultGCPRegion
+		}
+
+		return defaultAWSRegion
+	}
+
+	return str
+}
