@@ -24,15 +24,16 @@ func NewAzureRMKubernetesClusterNodePool(d *schema.ResourceData, u *schema.Usage
 	region := lookupRegion(d, []string{"kubernetes_cluster_id"})
 
 	nodeCount := decimal.NewFromInt(1)
-	if d.Get("node_count").Type != gjson.Null {
-		nodeCount = decimal.NewFromInt(d.Get("node_count").Int())
-	}
 
 	// if the node count is not set explicitly let's take the min_count.
-	if d.Get("min_count").Type != gjson.Null && nodeCount.Equal(decimal.NewFromInt(1)) {
+	if d.Get("min_count").Type != gjson.Null {
 		nodeCount = decimal.NewFromInt(d.Get("min_count").Int())
 	}
 
+	if d.Get("node_count").Type != gjson.Null {
+		nodeCount = decimal.NewFromInt(d.Get("node_count").Int())
+	}
+
 	if u != nil && u.Get("nodes").Exists() {
 		nodeCount = decimal.NewFromInt(u.Get("nodes").Int())
 	}
@@ -48,7 +49,13 @@ func aksClusterNodePool(name, region string, n gjson.Result, nodeCount decimal.D
 		Name: name,
 	}
 	instanceType := n.Get("vm_size").String()
-	costComponents = append(costComponents, linuxVirtualMachineCostComponent(region, instanceType, nil))
+
+	var monthlyHours *float64
+	if u != nil && u.Get("monthly_hrs").Exists() {
+		monthlyHours = u.GetFloat("monthly_hrs")
+	}
+
+	costComponents = append(costComponents, linuxVirtualMachineCostComponent(region, instanceType, monthlyHours))
 	mainResource.CostComponents = costComponents
 	schema.MultiplyQuantities(mainResource, nodeCount)
 
