@@ -3,6 +3,8 @@ package azure
 import (
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/shopspring/decimal"
+	"github.com/tidwall/gjson"
+	"strings"
 )
 
 func GetAzureRMLoadBalancerRuleRegistryItem() *schema.RegistryItem {
@@ -19,6 +21,16 @@ func NewAzureRMLoadBalancerRule(d *schema.ResourceData, u *schema.UsageData) *sc
 	region := lookupRegion(d, []string{"loadbalancer_id"})
 	region = convertRegion(region)
 
+	lbSku := getParentLbSku(d.References("loadbalancer_id"))
+
+	if lbSku == "" || strings.ToLower(lbSku) == "basic" {
+		return &schema.Resource{
+			Name:      d.Address,
+			NoPrice:   true,
+			IsSkipped: true,
+		}
+	}
+
 	var costComponents []*schema.CostComponent
 	costComponents = append(costComponents, rulesCostComponent(region))
 
@@ -28,6 +40,18 @@ func NewAzureRMLoadBalancerRule(d *schema.ResourceData, u *schema.UsageData) *sc
 	}
 }
 
+func getParentLbSku(lb []*schema.ResourceData) string {
+	if len(lb) != 1 {
+		return ""
+	}
+
+	if lb[0].Get("sku").Type != gjson.Null {
+		return lb[0].Get("sku").String()
+	}
+
+	return "Basic" // default to basic
+}
+
 func rulesCostComponent(region string) *schema.CostComponent {
 	return &schema.CostComponent{
 		Name:           "Rule usage",
