@@ -27,6 +27,10 @@ func GetSpecialContext(d *schema.ResourceData) map[string]interface{} {
 }
 
 func GetResourceRegion(resourceType string, v gjson.Result) string {
+	if v.Get("region").Exists() && v.Get("region").String() != "" {
+		return v.Get("region").String()
+	}
+
 	return ""
 }
 
