@@ -131,9 +131,9 @@ func NewHCLProvider(ctx *config.ProjectContext, config *HCLProviderConfig, opts
 	runCtx := ctx.RunContext
 	locatorConfig := &hcl.ProjectLocatorConfig{ExcludedSubDirs: ctx.ProjectConfig.ExcludePaths, ChangedObjects: runCtx.VCSMetadata.Commit.ChangedObjects, UseAllPaths: ctx.ProjectConfig.IncludeAllPaths}
 
-	wd := ctx.RunContext.Config.RepoPath()
+	cachePath := ctx.RunContext.Config.CachePath()
 	initialPath := ctx.ProjectConfig.Path
-	if filepath.IsAbs(wd) {
+	if filepath.IsAbs(cachePath) {
 		abs, err := filepath.Abs(initialPath)
 		if err != nil {
 			logger.WithError(err).Warnf("could not make project path absolute to match provided --config-file/--path path absolute, this will result in module loading failures")
@@ -141,8 +141,7 @@ func NewHCLProvider(ctx *config.ProjectContext, config *HCLProviderConfig, opts
 			initialPath = abs
 		}
 	}
-
-	loader := modules.NewModuleLoader(wd, credsSource, logger, ctx.RunContext.ModuleMutex)
+	loader := modules.NewModuleLoader(cachePath, credsSource, ctx.RunContext.Config.TerraformSourceMap, logger, ctx.RunContext.ModuleMutex)
 	parsers, err := hcl.LoadParsers(
 		initialPath,
 		loader,
